#include <Wire.h>
#include <Adafruit_VL53L0X.h>

// Create an instance of the sensor
Adafruit_VL53L0X lox = Adafruit_VL53L0X();

// Define the pin for the vibration module
const int vibrationPin = 9;

// Fixed duration for vibration (in milliseconds)
const int vibrationDuration = 100; // 100 ms
unsigned long previousVibrationTime = 0;

void setup() {
  Serial.begin(115200);
  pinMode(vibrationPin, OUTPUT);
  digitalWrite(vibrationPin, LOW); // Ensure vibration module is off initially

  Serial.println("VL53L0X Distance Measurement");

  // Initialize the sensor
  if (!lox.begin()) {
    Serial.println("Failed to find VL53L0X chip");
    while (1) {
      delay(10);
    }
  }
}

void loop() {
  VL53L0X_RangingMeasurementData_t measure;
  lox.rangingTest(&measure, false); // Pass true to get continuous readings

  if (measure.RangeStatus != 4) {  // Phase failures have incorrect data
    int distance_mm = measure.RangeMilliMeter;

    Serial.print("Distance (mm): ");
    Serial.println(distance_mm);

    // Control vibration based on distance
    unsigned long currentTime = millis();

    // Determine vibration interval based on distance
    unsigned long vibrationInterval;

    if (distance_mm > 2438) { // Greater than 8 feet
      // No vibration
      digitalWrite(vibrationPin, LOW);
    } else if (distance_mm > 2133) { // Between 7 and 8 feet
      vibrationInterval = 3500; // 3.5 seconds
    } else if (distance_mm > 1829) { // Between 6 and 7 feet
      vibrationInterval = 3000; // 3 seconds
    } else if (distance_mm > 1524) { // Between 5 and 6 feet
      vibrationInterval = 2500; // 2.5 seconds
    } else if (distance_mm > 1219) { // Between 4 and 5 feet
      vibrationInterval = 2000; // 2 seconds
    } else if (distance_mm > 914) { // Between 3 and 4 feet
      vibrationInterval = 1500; // 1.5 seconds
    } else if (distance_mm > 610) { // Between 2 and 3 feet
      vibrationInterval = 1000; // 1 second
    } else if (distance_mm > 457) { // Between 1.5 and 2 feet
      vibrationInterval = 750; // 0.75 seconds
    } else if (distance_mm > 305) { // Between 1 and 1.5 feet
      vibrationInterval = 500; // 0.5 seconds
    } else if (distance_mm > 152) { // Between 6 and 12 inches
      vibrationInterval = 250; // 0.25 seconds
    } else { // Closer than 6 inches
      vibrationInterval = 100; // 0.1 seconds
    }

    // Control vibration based on the calculated interval
    if (currentTime - previousVibrationTime >= vibrationInterval) {
      digitalWrite(vibrationPin, HIGH); // Turn on vibration
      delay(vibrationDuration); // Keep it on for a fixed duration
      digitalWrite(vibrationPin, LOW); // Turn it off
      previousVibrationTime = currentTime; // Update the last vibration time
    }
  } else {
    Serial.println("Out of range");
    digitalWrite(vibrationPin, LOW); // Ensure vibration is off
    delay(500); // Delay to avoid spamming the serial monitor
  }

  delay(10); // Adjust delay as needed
}
